datablock AudioProfile(welderHitSound)
{
   filename    = "./welderHit.wav";
   description = AudioClosest3d;
   preload = true;
};

datablock AudioProfile(sentryHealSound)
{
   filename    = "./sentrySteam.wav";
   description = AudioClosest3d;
   preload = true;
};

datablock AudioProfile(sentryUpgradeSound)
{
   filename    = "./sentryUpgrade.wav";
   description = AudioClosest3d;
   preload = true;
};

//effects
datablock ExplosionData(welderExplosion)
{
   //explosionShape = "";
   lifeTimeMS = 500;

   particleEmitter = gunSmokeEmitter;
   particleDensity = 10;
   particleRadius = 0.001;

   faceViewer     = true;
   explosionScale = "1 1 1";

   shakeCamera = false;
   camShakeFreq = "20.0 22.0 20.0";
   camShakeAmp = "1.0 1.0 1.0";
   camShakeDuration = 0.5;
   camShakeRadius = 10.0;

   // Dynamic light
   lightStartRadius = 0;
   lightEndRadius = 0;
   lightStartColor = "00.0 0.2 0.6";
   lightEndColor = "0 0 0";
};


//projectile
AddDamageType("Welder",   '<bitmap:add-ons/Weapon_Sword/CI_Sword> %1',    '%2 <bitmap:add-ons/Weapon_Sword/CI_Sword> %1',0.75,1);
datablock ProjectileData(welderProjectile)
{
   directDamage        = 0;
   directDamageType  = $DamageType::Welder;
   radiusDamageType  = $DamageType::Welder;
   explosion           = welderExplosion;
   //particleEmitter     = gunFlashEmitter;

   muzzleVelocity      = 100;
   velInheritFactor    = 0;

   armingDelay         = 0;
   lifetime            = 66;
   fadeDelay           = 0;
   bounceElasticity    = 0;
   bounceFriction      = 0;
   isBallistic         = false;
   gravityMod = 0.0;

   hasLight    = false;
   lightRadius = 3.0;
   lightColor  = "0 0 0.5";

   uiName = "Welder Slice";
};


//////////
// item //
//////////
datablock ItemData(welderItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./welder.dts";
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Welder";
	iconName = "./icon_welder";
	doColorShift = false;
	colorShiftColor = "0.471 0.471 0.471 1.000";

	 // Dynamic properties defined by the scripts
	image = welderImage;
	canDrop = true;
};

////////////////
//weapon image//
////////////////
datablock ShapeBaseImageData(welderImage)
{
   // Basic Item properties
   shapeFile = "./welder.dts";
   emap = true;
   mountPoint = 0;
   offset = "0 0 0";
   eyeOffset = 0; //"0.7 1.2 -0.5";
   rotation = eulerToMatrix( "0 0 0" );
   correctMuzzleVector = true;

   // Add the WeaponImage namespace as a parent, WeaponImage namespace
   // provides some hooks into the inventory system.
   className = "WeaponImage";

   // Projectile && Ammo.
   item = welderItem;
   ammo = " ";
   projectile = welderProjectile;
   projectileType = Projectile;

   //melee particles shoot from eye node for consistancy
   melee = false;
   doRetraction = false;
   //raise your arm up or not
   armReady = true;

   //casing = " ";
   doColorShift = true;
   colorShiftColor = "0.471 0.471 0.471 1.000";

   // Images have a state system which controls how the animations
   // are run, which sounds are played, script callbacks, etc. This
   // state system is downloaded to the client so that clients can
   // predict state changes and animate accordingly.  The following
   // system supports basic ready->fire->reload transitions as
   // well as a no-ammo->dryfire idle state.

   // Initial start up state
	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.1;
	stateTransitionOnTimeout[0]      = "Ready";

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "PreFire";
	stateAllowImageChange[1]         = true;

	stateName[2]			= "PreFire";
	stateScript[2]                  = "onPreFire";
	stateAllowImageChange[2]        = false;
	stateTimeoutValue[2]            = 0.05;
	stateTransitionOnTimeout[2]     = "Fire";

	stateName[3]                    = "Fire";
	stateTransitionOnTimeout[3]     = "CheckFire";
	stateTimeoutValue[3]            = 0.05;
	stateFire[3]                    = true;
	stateEmitter[3]					= gunFlashEmitter;
	stateSound[3]					= welderHitSound;
	stateEmitterTime[3]				= 0.08;
	stateEmitterNode[3]				= "muzzleNode";
	stateAllowImageChange[3]        = false;
	stateSequence[3]                = "Fire";
	stateScript[3]                  = "onFire";
	stateWaitForTimeout[3]		= true;

	stateName[4]			= "CheckFire";
	stateTransitionOnTriggerUp[4]	= "StopFire";
	stateTransitionOnTriggerDown[4]	= "Fire";
	
	stateName[5]                    = "StopFire";
	stateTransitionOnTimeout[5]     = "Ready";
	stateTimeoutValue[5]            = 0.2;
	stateAllowImageChange[5]        = false;
	stateWaitForTimeout[5]		= true;
	stateSequence[5]                = "StopFire";
	stateScript[5]                  = "onStopFire";


};

function welderProjectile::onCollision(%this,%obj,%col,%fade,%pos,%normal)
{
	if(%col.dataBlock $= "")
	{
		parent::onCollision(%this, %obj, %col, %fade, %pos, %normal);
		return;
	}
	
	if(%col.dataBlock.getName() $= "playerSentryTop")
		%sentry = %col;
	if(%col.dataBlock.getName() $= "playerSentryBottom")
		{
		%sentry = %col.sentryTop;
		%col.setDamageLevel(%col.getDamageLevel()-2);
		%sentry.setDamageLevel(%col.getDamageLevel()-2);
		serverPlay3D(sentryHealSound, %sentry.getPosition());
		bottomprint(%obj.client,"<just:center><font:impact:38><color:ffffff>Healing the sentry..." @ %col.getDatablock().maxDamage - %col.getDamageLevel() @ "<color:fff000><font:impact:32> out of 150 hit points left." ,5);
		}
	
	if(!isObject(%sentry))
	{
		parent::onCollision(%this, %obj, %col, %fade, %pos, %normal);
		return;
	}
	
	//note: %sentry will always be the sentry's top
	
	%sentry.sentryXP += $sentryWelderUpgradeRate;
	%kit = %sentry.sentryKit;
	%level = %sentry.sentryLevel;

	if(%sentry.sentryXP >= $sentryUpgradeThreshold_[%kit @ "_" @ %level + 1] && $sentryImage_[%kit @ "_" @ %level + 1] !$= "")
	{
		//UPRADIN' A SENTRY
		%sentry.sentryLevel++;
		%sentry.sentryXP = 0; //reset XP
		%level++;
		%sentry.setVelocity("0 0" SPC getWord(%obj.getVelocity(),4));
		%sentry.mountImage($sentryImage_[%kit @ "_" @ %level], 0);
		serverPlay3D(sentryUpgradeSound, %sentry.getPosition());
		messageClient(%obj.client, "", "\c3Sentry upgraded!");
%pos = %sentry.getPosition();

%p = new Projectile()
  {
     dataBlock = toolboxExplosion2Projectile;
     initialPosition = %pos;
     initialVelocity = "0 0 1";
     client = %obj.client;
     sourceClient = %obj.client;
  };
MissionCleanup.add(%p);
%p.explode();
	}

	if(%sentry.sentryLevel == 1)
	{
	centerprint(%obj.client,"<br><br><br><br><br><br><font:impact:38><color:ffffff>" @ %sentry.sentryXP @ "/" @ $sentryUpgradeThreshold_Default_2 @ "<color:fff000><font:impact:32> upgrade power: Sentry is currently level <font:impact:38><color:ffffff>1." ,5);
	}
	if(%sentry.sentryLevel == 2)
	{
	centerprint(%obj.client,"<br><br><br><br><br><br><font:impact:38><color:ffffff>" @ %sentry.sentryXP @ "/" @ $sentryUpgradeThreshold_Default_3 @ "<color:fff000><font:impact:32> upgrade power: Sentry is currently level <font:impact:38><color:ffffff>2." ,5);
	}
	if (%sentry.sentryLevel == 3)
	{
	centerprint(%obj.client,"<br><br><br><br><br><br><color:fff000><font:impact:32>This sentry is already fully upgraded, at level <font:impact:38><color:ffffff>3." ,5);
	}
}
